.. aind-metadata-mapper documentation master file, created by
   sphinx-quickstart on Mon Sep 16 14:00:28 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to this repository's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   UserGuide
   Contributing
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`